@@ -1,7 +1,7 @@
 package Git::Bunch;
 
 our $DATE = '2015-07-25'; # DATE
-our $VERSION = '0.45'; # VERSION
+our $VERSION = '0.46'; # VERSION
 
 use 5.010001;
 use strict;
@@ -409,7 +409,7 @@ sub check_bunch {
     [200,
      $has_unclean ? "Some repos unclean" : "All repos clean",
      \%res,
-     {'func.res'=>\%res}];
+     {'cmdline.result'=>'', 'func.res'=>\%res}];
 }
 
 sub _sync_repo {
@@ -880,7 +880,7 @@ Git::Bunch - Manage gitbunch directory (directory which contain git repos)
 
 =head1 VERSION
 
-This document describes version 0.45 of Git::Bunch (from Perl distribution Git-Bunch), released on 2015-07-25.
+This document describes version 0.46 of Git::Bunch (from Perl distribution Git-Bunch), released on 2015-07-25.
 
 =head1 SYNOPSIS
 
@@ -1292,7 +1292,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Git-Bunch>
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Git-Bunch>.
+Source repository is at L<https://github.com/sharyanto/perl-Git-Bunch>.
 
 =head1 BUGS
 
